@@ -7,14 +7,14 @@ import (
 	"os"
 	"testing"
 
-	operatorsv1 "github.com/open-cluster-management/multiclusterhub-operator/pkg/apis/operator/v1"
-	"github.com/open-cluster-management/multiclusterhub-operator/pkg/utils"
+	operatorsv1 "github.com/stolostron/multiclusterhub-operator/pkg/apis/operator/v1"
+	"github.com/stolostron/multiclusterhub-operator/pkg/utils"
 )
 
 func Test_readManifestFile(t *testing.T) {
 	t.Run("Get manifest", func(t *testing.T) {
 		os.Setenv(ManifestsPathEnvVar, "../../image-manifests")
-		version := "2.3.4"
+		version := "2.3.6"
 		_, err := readManifestFile(version)
 		if err != nil {
 			t.Errorf("readManifestFile() error = %v, wantErr %v", err, nil)
@@ -32,7 +32,7 @@ func Test_readManifestFile(t *testing.T) {
 
 	t.Run("Env var missing", func(t *testing.T) {
 		os.Unsetenv(ManifestsPathEnvVar)
-		version := "2.3.4"
+		version := "2.3.6"
 		_, err := readManifestFile(version)
 		if err == nil {
 			t.Errorf("readManifestFile() did not return error")
@@ -44,8 +44,8 @@ func Test_buildFullImageReference(t *testing.T) {
 	mi := ManifestImage{
 		ImageKey:     "test_app",
 		ImageName:    "test-app",
-		ImageVersion: "2.3.4",
-		ImageRemote:  "quay.io/open-cluster-management",
+		ImageVersion: "2.3.6",
+		ImageRemote:  "quay.io/stolostron",
 		ImageDigest:  "sha256:abc123",
 	}
 	mch := &operatorsv1.MultiClusterHub{}
@@ -67,7 +67,7 @@ func Test_buildFullImageReference(t *testing.T) {
 		{
 			name: "Default (sha format)",
 			args: args{mch1, mi},
-			want: "quay.io/open-cluster-management/test-app@sha256:abc123",
+			want: "quay.io/stolostron/test-app@sha256:abc123",
 		},
 		{
 			name: "Custom registry",
