@@ -152,7 +152,7 @@ var (
 		Resource: "discoveryconfigs",
 	}
 	// DefaultImageRegistry ...
-	DefaultImageRegistry = "quay.io/open-cluster-management"
+	DefaultImageRegistry = "quay.io/stolostron"
 	// DefaultImagePullSecretName ...
 	DefaultImagePullSecretName = "multiclusterhub-operator-pull-secret"
 
@@ -869,7 +869,7 @@ func ValidateMCH() error {
 	Expect(err).Should(BeNil())
 	v, err := semver.NewVersion(currentVersion)
 	Expect(err).Should(BeNil())
-	c, err := semver.NewConstraint(">= 2.3.4")
+	c, err := semver.NewConstraint(">= 2.3.6")
 	Expect(err).Should(BeNil())
 	if c.Check(v) {
 		By("- Ensuring image manifest configmap is created")
@@ -1041,6 +1041,20 @@ func validateManagedClusterConditions() error {
 	}
 }
 
+func ValidateDeploymentPolicies() error {
+	unstructuredDeployments := listByGVR(DynamicKubeClient, GVRDeployment, MCHNamespace, 60, 3)
+
+	for _, deployment := range unstructuredDeployments.Items {
+		deploymentName := deployment.GetName()
+		if deploymentName != "multicluster-operators-application" && deploymentName != "hive-operator" && deploymentName != "multicluster-operators-channel" && deploymentName != "multicluster-operators-hub-subscription" && deploymentName != "multicluster-operators-standalone-subscription" {
+			policy := deployment.Object["spec"].(map[string]interface{})["template"].(map[string]interface{})["spec"].(map[string]interface{})["containers"].([]interface{})[0].(map[string]interface{})["imagePullPolicy"]
+			fmt.Println(fmt.Sprintf(deploymentName))
+			Expect(policy).To(BeEquivalentTo("IfNotPresent"))
+		}
+	}
+	return nil
+}
+
 // ToggleDisableHubSelfManagement toggles the value of spec.disableHubSelfManagement from true to false or false to true
 func ToggleDisableHubSelfManagement(disableHubSelfImport bool) error {
 	mch, err := DynamicKubeClient.Resource(GVRMultiClusterHub).Namespace(MCHNamespace).Get(context.TODO(), MCHName, metav1.GetOptions{})
